---
title: utils
sidebarTitle: utils
---

# `catalax.neural.utils`

## Functions

### `save` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/neural/utils.py#L5" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
save(filename, hyperparams, model)
```
